Wingify class
The main entry point for the Wingify FME Flutter SDK.
Provides initialization, feature-flag evaluation, event tracking, and user attribute APIs.
Constructors
- Wingify()
Properties
- accountId ↔ int?
-
getter/setter pairinherited
- fmePlugin ↔ VwoFmeFlutterSdkPlatform?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkKey ↔ String?
-
getter/setter pairinherited
Methods
-
attach(
FmeInitOptions options) → Future< void> -
Initializes the native SDK for
optionsand registers this client.inherited -
clearInstance(
) → Future< bool> -
Clears this client instance.
inherited
-
getFlag(
{required String featureKey, required FmeUserContext context}) → Future< GetFlag?> -
Gets the value of a feature flag.
inherited
-
invokeSetAlias(
{required FmeUserContext context, required String alias}) → Future< bool> -
Shared setAlias implementation for VWO and Wingify.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAlias(
{required WingifyUserContext context, required String alias}) → Future< bool> ? - Links a temporary user ID to an authenticated user ID.
-
setAttribute(
{required Map< String, dynamic> attributes, required FmeUserContext context}) → Future<bool> -
Sets user attributes. Returns
falseif the SDK is not initialized.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
trackEvent(
{required String eventName, required FmeUserContext context, Map< String, dynamic> ? eventProperties}) → Future<Map< String, bool> ?> -
Tracks an event.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getInstance(
{required int accountId, required String sdkKey}) → Wingify? - Gets an existing Wingify instance previously created via init.
-
init(
WingifyInitOptions options) → Future< Wingify?> - Initializes the Wingify SDK.
-
logMessage(
String message) → void -
Prints a message in debug mode only.
override