GetFlag class

Represents a feature flag and its associated variables.

Constructors

GetFlag({required bool isEnabled, required List<Variable> variables})
GetFlag.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List<Variable>
final

Methods

getRecommendationDisplayConfig(String? key) Map<String, dynamic>?
getVariable(String? key, dynamic defaultValue) → dynamic
getVariables() List<Map<String, dynamic>>
isEnabled() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIsEnabled(bool value) → void
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override