WingifyUserContext class

Identifies a user for feature-flag evaluation, tracking, and targeting.

Implemented types
Implementers

Constructors

WingifyUserContext({String? id, Map<String, dynamic>? customVariables, bool shouldUseDeviceIdAsUserId = false})

Properties

customVariables Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldUseDeviceIdAsUserId bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts the WingifyUserContext object into a Map.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited