WingifyInitOptions class
Initialization options for the Wingify FME SDK.
- Implemented types
- Implementers
Constructors
-
WingifyInitOptions({required String sdkKey, required int accountId, Map<
String, dynamic> ? logger, Map<String, String> ? gatewayService, int? pollInterval, int? cachedSettingsExpiryTime, dynamic integrations(Map<String, dynamic> )?, int batchMinSize = -1, int batchUploadTimeInterval = -1, bool isUsageStatsDisabled = false, bool? isAliasingEnabled = false})
Properties
- accountId → int
-
final
- batchMinSize → int
-
Optional: Minimum size of Batch to upload
final
- batchUploadTimeInterval → int
-
Optional: Batch upload time interval in milliseconds. Please specify at least few minutes
final
- cachedSettingsExpiryTime → int?
-
final
-
gatewayService
→ Map<
String, String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
integrations
→ dynamic Function(Map<
String, dynamic> )? -
final
- isAliasingEnabled ↔ bool?
-
Optional: if aliasing is enabled
getter/setter pairoverride-getter
- isUsageStatsDisabled ↔ bool
-
Optional: Usage stats should always be collected, don't collect if isUsageStatsDisabled flag is true
getter/setter pairoverride-getter
-
logger
→ Map<
String, dynamic> ? -
final
-
platformMeta
↔ Map<
String, dynamic> -
Internal SDK metadata.
getter/setter pairoverride-getter
- pollInterval → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkKey → String
-
final
- useWingifyApi → bool
-
Whether to initialize through the Wingify native API (
true) or the legacy VWO native API (false).no setteroverride -
vwo_meta
↔ Map<
String, dynamic> -
Legacy name for platformMeta. Supports assignment and in-place mutation
like the v1.9.0
vwo_metafield.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited